pub struct FeedHandler { /* private fields */ }Expand description
Deserializes incoming WebSocket messages into venue-specific types.
The handler owns the WebSocketClient exclusively within the lock-free I/O boundary, eliminating RwLock contention on the hot path.
Implementations
Sourceimpl FeedHandler
impl FeedHandler
Sourcepub fn new(
cmd_rx: UnboundedReceiver<HandlerCommand>,
out_tx: UnboundedSender<DydxWsOutputMessage>,
raw_rx: UnboundedReceiver<Message>,
client: WebSocketClient,
signal: Arc<AtomicBool>,
subscriptions: SubscriptionState,
) -> Self
pub fn new( cmd_rx: UnboundedReceiver<HandlerCommand>, out_tx: UnboundedSender<DydxWsOutputMessage>, raw_rx: UnboundedReceiver<Message>, client: WebSocketClient, signal: Arc<AtomicBool>, subscriptions: SubscriptionState, ) -> Self
Creates a new FeedHandler.
Sourcepub async fn run(&mut self)
pub async fn run(&mut self)
Main processing loop for the handler.
Panics
This method will not panic. The expect call on iter.next() is safe
because we explicitly check that msgs is not empty before calling it.
Sourcepub async fn handle_message(
&mut self,
msg: DydxWsMessage,
) -> DydxWsResult<Vec<DydxWsOutputMessage>>
pub async fn handle_message( &mut self, msg: DydxWsMessage, ) -> DydxWsResult<Vec<DydxWsOutputMessage>>
Handles control messages from the fallback parsing path.
Channel data is handled directly via handle_feed_message().
Errors
Returns an error if the message cannot be processed.